﻿using System;
using Xunit;
using Bunit;
using BlazorAppForTesting.Data;
using BlazorAppForTesting.Shared;
using Microsoft.Extensions.DependencyInjection;

namespace BlazorAppForTestingTests
{
    public class WeatherForecastServiceTests : TestContext
    {
        [Fact]
        public void WeatherForecastZeroCShouldBe32F()
        {
            var forecast = new WeatherForecast();
            forecast.TemperatureC = 0;
            Assert.Equal(32, forecast.TemperatureF);
        }

        [Theory]
        [InlineData(-1)]
        [InlineData(-10)]
        [InlineData(-100)]
        public void WeatherForecastBelowZeroShouldBeBelow32F(int value)
        {
            var forecast = new WeatherForecast();
            forecast.TemperatureC = value;
            Assert.True(forecast.TemperatureF < 32);
        }

        [Fact]
        public void AddWeatherForecastService()
        {
            // Add the service
            var item = new ServiceDescriptor(typeof(IWeatherForecastService), new MockWeatherService());
            Services.Add(item);

            // RenderComponent will inject the service in the WeatherForecasts component
            // when it is instantiated and rendered.
            var cut = RenderComponent<WeatherForecasts>();

            // Assert that service is injected
            Assert.NotNull(cut.Instance.Forecasts);

        }
    }
}
